@@ -6,9 +6,9 @@
 
 """A simple Twitter client made with pyqt4"""
 
-from PyQt4.QtGui import *
-from PyQt4.QtCore import *
-from PyQt4.QtMaemo5 import *
+from PySide.QtGui import *
+from PySide.QtCore import *
+from PySide.QtMaemo5 import *
 
 import khweeteur
 import twitter
@@ -25,7 +25,7 @@ from nwmanager import NetworkManager
 import dbus.service
 import dbus.mainloop.qt
 
-__version__ = '0.0.14'
+__version__ = '0.0.15'
 AVATAR_CACHE_FOLDER = os.path.join(os.path.expanduser("~"),'.khweeteur','cache')
 CACHE_PATH = os.path.join(os.path.expanduser("~"), '.khweeteur')
 KHWEETEUR_TWITTER_CONSUMER_KEY = 'uhgjkoA2lggG4Rh0ggUeQ'
@@ -105,7 +105,7 @@ class KhweeteurWorker(QThread):
         
     def downloadProfileImage(self,status):
         if type(status)!=twitter.DirectMessage:
-            cache = os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(status.user.profile_image_url))
+            cache = os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(status.user.profile_image_url.replace('/','_')))
             if not(os.path.exists(cache)):
                 try:
                     urlretrieve(status.user.profile_image_url, cache)
@@ -121,8 +121,8 @@ class KhweeteurWorker(QThread):
         try:
             mlist = []
             avatars_url={}
-            if (self.settings.value("twitter_access_token_key").toString()!=''): 
-                api = twitter.Api(input_encoding='utf-8',username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, access_token_key=str(self.settings.value("twitter_access_token_key").toString()),access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
+            if (self.settings.value("twitter_access_token_key")!=''): 
+                api = twitter.Api(input_encoding='utf-8',username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, access_token_key=str(self.settings.value("twitter_access_token_key")),access_token_secret=str(self.settings.value("twitter_access_token_secret")))
                 for status in api.GetSearch(unicode(self.search_keyword).encode('UTF-8')):
                     if status.created_at_in_seconds > current_dt:
                         downloadProfileImage(status)
@@ -132,8 +132,8 @@ class KhweeteurWorker(QThread):
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
 
         try:
-            if (self.settings.value("twitter_access_token_key").toString()!=''): 
-                api = twitter.Api(base_url='http://identi.ca/api/', username=KHWEETEUR_IDENTICA_CONSUMER_KEY,password=KHWEETEUR_IDENTICA_CONSUMER_SECRET, access_token_key=str(self.settings.value("identica_access_token_key").toString()),access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))
+            if (self.settings.value("twitter_access_token_key")!=''): 
+                api = twitter.Api(base_url='http://identi.ca/api/', username=KHWEETEUR_IDENTICA_CONSUMER_KEY,password=KHWEETEUR_IDENTICA_CONSUMER_SECRET, access_token_key=str(self.settings.value("identica_access_token_key")),access_token_secret=str(self.settings.value("identica_access_token_secret")))
                 for status in api.GetSearch(unicode(self.search_keyword).encode('UTF-8'),per_page=50):
                     if status.created_at_in_seconds > current_dt:
                         downloadProfileImage(status)
@@ -142,7 +142,7 @@ class KhweeteurWorker(QThread):
             print 'Error during refresh : ',e.message
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
 
-            if ((self.settings.value("twitter_access_token_key").toString()!='')) or ((self.settings.value("identica_access_token_key").toString()!='')): 
+            if ((self.settings.value("twitter_access_token_key")!='')) or ((self.settings.value("identica_access_token_key")!='')): 
 
                 mlist.sort()
                 self.emit(SIGNAL("newStatuses(PyQt_PyObject)"),mlist)
@@ -155,8 +155,8 @@ class KhweeteurWorker(QThread):
         try:
             mlist = []
             avatars_url={}
-            if (self.settings.value("twitter_access_token_key").toString()!=''): 
-                api = twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, access_token_key=str(self.settings.value("twitter_access_token_key").toString()),access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
+            if (self.settings.value("twitter_access_token_key")!=''): 
+                api = twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, access_token_key=str(self.settings.value("twitter_access_token_key")),access_token_secret=str(self.settings.value("twitter_access_token_secret")))
                 for status in api.GetFriendsTimeline(count=100):
                     if status.created_at_in_seconds > current_dt:
                         downloadProfileImage(status)
@@ -180,8 +180,8 @@ class KhweeteurWorker(QThread):
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
 
         try:
-            if (self.settings.value("identica_access_token_key").toString()!=''): 
-                api = twitter.Api(base_url='http://identi.ca/api/', username=KHWEETEUR_IDENTICA_CONSUMER_KEY,password=KHWEETEUR_IDENTICA_CONSUMER_SECRET, access_token_key=str(self.settings.value("identica_access_token_key").toString()),access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))
+            if (self.settings.value("identica_access_token_key")!=''): 
+                api = twitter.Api(base_url='http://identi.ca/api/', username=KHWEETEUR_IDENTICA_CONSUMER_KEY,password=KHWEETEUR_IDENTICA_CONSUMER_SECRET, access_token_key=str(self.settings.value("identica_access_token_key")),access_token_secret=str(self.settings.value("identica_access_token_secret")))
                 for status in api.GetFriendsTimeline(count=100):
                     if status.created_at_in_seconds > current_dt:
                         downloadProfileImage(status)
@@ -207,7 +207,7 @@ class KhweeteurWorker(QThread):
             print 'Error during refresh : ',e.message
             self.emit(SIGNAL("info(PyQt_PyObject)"),e.message)
 
-            if ((self.settings.value("twitter_access_token_key").toString()!='')) or ((self.settings.value("identica_access_token_key").toString()!='')): 
+            if ((self.settings.value("twitter_access_token_key")!='')) or ((self.settings.value("identica_access_token_key")!='')): 
 
                 mlist.sort()
 
@@ -292,9 +292,10 @@ class KhweetsModel(QAbstractListModel):
                              variant.id,
                              variant.user.screen_name,
                              variant.text,
-                             variant.user.profile_image_url,
+                             variant.user.profile_image_url.replace('/','_'),
                              self.GetRelativeCreatedAt(variant.created_at_in_seconds),))
-                        self._avatars[variant.user.profile_image_url] = QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url))))
+#                        self._avatars[variant.user.profile_image_url] = QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url))))
+                        self._avatars[variant.user.profile_image_url] = (QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url.replace('/','_')))))
 #                             QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url))))))
                     else:
                         self._items.insert(0,
@@ -323,7 +324,8 @@ class KhweetsModel(QAbstractListModel):
                          variant.text,
                          variant.user.profile_image_url,
                          self.GetRelativeCreatedAt(variant.created_at_in_seconds),))
-                    self._avatars[variant.user.profile_image_url] = QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url))))
+                    self._avatars[variant.user.profile_image_url] = (QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url))))
+#                    self._avatars[variant.user.profile_image_url] = QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url))))
                 else:
                     self._items.insert(0,
                          (variant.created_at_in_seconds,
@@ -393,7 +395,9 @@ class KhweetsModel(QAbstractListModel):
                     self._items = self._items[:index]
                     break
             for item in self._items:
-                self._avatars[item[4]] = QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(item[4]))))
+#                self._avatars[item[4]] = QVariant(QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(item[4]))))
+                if item[4]!=None:
+                    self._avatars[item[4]] = (QIcon(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(item[4].replace('/','_')))))
             self._items.sort()
             self._items.reverse()
             QObject.emit(self, SIGNAL("dataChanged(const QModelIndex&, const QModelIndex &)"), self.createIndex(0,0), self.createIndex(0,len(self._items)))
@@ -405,17 +409,21 @@ class KhweetsModel(QAbstractListModel):
                 status = status +'\n'+ self._items[index.row()][5]     
             if self.display_screenname:
                 status = self._items[index.row()][2]+ ' : ' + status            
-            return QVariant(status)
+#            return QVariant(status)
+            return (status)
         elif role == Qt.DecorationRole:            
             if self.display_avatar:
                 try:
                     return self._avatars[self._items[index.row()][4]]
                 except:
-                    return QVariant()
+#                    return QVariant()
+                    return None
             else:
-                return QVariant()
+ #               return QVariant()
+                return None
         else:
-            return QVariant()
+#            return QVariant()
+            return None
 
 class KhweetsView(QListView):
     def __init__(self,parent=None):
@@ -442,7 +450,7 @@ class KhweeteurAbout(QMainWindow):
         awidget.setMinimumSize(480,700)
         awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
         aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
-        scroller = aboutScrollArea.property("kineticScroller").toPyObject()
+        scroller = aboutScrollArea.property("kineticScroller") #.toPyObject()
         scroller.setEnabled(True)
 
         aboutLayout = QVBoxLayout(awidget)
@@ -486,12 +494,39 @@ class KhweeteurPref(QMainWindow):
         self.loadPrefs()
 
     def loadPrefs(self):
-        self.refresh_value.setValue(self.settings.value("refreshInterval").toInt()[0])
-        self.displayUser_value.setCheckState(self.settings.value("displayUser").toInt()[0])
-        self.displayAvatar_value.setCheckState(self.settings.value("displayAvatar").toInt()[0])
-        self.displayTimestamp_value.setCheckState(self.settings.value("displayTimestamp").toInt()[0])
-        self.useNotification_value.setCheckState(self.settings.value("useNotification").toInt()[0])
-        self.useSerialization_value.setCheckState(self.settings.value("useSerialization").toInt()[0])
+#        self.refresh_value.setValue(self.settings.value("refreshInterval").toInt()[0])
+#        self.displayUser_value.setCheckState(self.settings.value("displayUser").toInt()[0])
+#        self.displayAvatar_value.setCheckState(self.settings.value("displayAvatar").toInt()[0])
+#        self.displayTimestamp_value.setCheckState(self.settings.value("displayTimestamp").toInt()[0])
+#        self.useNotification_value.setCheckState(self.settings.value("useNotification").toInt()[0])
+#        self.useSerialization_value.setCheckState(self.settings.value("useSerialization").toInt()[0])
+        #Pyside
+        try:
+            self.refresh_value.setValue(int(self.settings.value("refreshInterval")))
+            
+            if self.settings.value("displayUser")!='0':
+                self.displayUser_value.setCheckState(Qt.Checked)
+            else:
+                self.displayUser_value.setCheckState(Qt.Unchecked)
+            if self.settings.value("displayAvatar")!='0':
+                self.displayAvatar_value.setCheckState(Qt.Checked)
+            else:
+                self.displayAvatar_value.setCheckState(Qt.Unchecked)
+            if self.settings.value("displayTimestamp")!='0':
+                self.displayTimestamp_value.setCheckState(Qt.Checked)
+            else:
+                self.displayTimestamp_value.setCheckState(Qt.Unchecked)
+            if self.settings.value("useNotification")!='0':
+                self.useNotification_value.setCheckState(Qt.Checked)
+            else:
+                self.useNotification_value.setCheckState(Qt.Unchecked)
+            if self.settings.value("useSerialization")!='0':
+                self.useSerialization_value.setCheckState(Qt.Checked)
+            else:
+                self.useSerialization_value.setCheckState(Qt.Unchecked)
+                
+        except:
+            KhweeteurNotification().info('Old pref format detected return to default')
 
     def savePrefs(self):
         self.settings.setValue('refreshInterval',self.refresh_value.value())
@@ -506,7 +541,7 @@ class KhweeteurPref(QMainWindow):
         self.savePrefs()
 
     def request_twitter_access_or_clear(self):
-        if self.settings.value('twitter_access_token').toBool():
+        if self.settings.value('twitter_access_token')=='true':
             self.settings.setValue('twitter_access_token_key',QString())
             self.settings.setValue('twitter_access_token_secret',QString())
             self.settings.setValue('twitter_access_token',False)
@@ -565,7 +600,8 @@ class KhweeteurPref(QMainWindow):
                 
     def request_identica_access_or_clear(self):
 
-        if self.settings.value('identica_access_token').toBool():
+
+        if self.settings.value('identica_access_token')=='true':
             self.settings.setValue('identica_access_token_key',QString())
             self.settings.setValue('identica_access_token_secret',QString())
             self.settings.setValue('identica_access_token',False)
@@ -631,19 +667,19 @@ class KhweeteurPref(QMainWindow):
         self.aWidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
         self.scrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding)
         self.scrollArea.setWidget(self.aWidget)
-        scroller = self.scrollArea.property("kineticScroller").toPyObject()
+        scroller = self.scrollArea.property("kineticScroller") #.toPyObject()
         scroller.setEnabled(True)
         self._main_layout = QGridLayout(self.aWidget)
 
         self._main_layout.addWidget(QLabel('Authorizations :'),0,0)
-        if self.settings.value('twitter_access_token').toBool():
+        if self.settings.value('twitter_access_token')=='true':
             self.twitter_value = QPushButton('Clear Twitter Auth')
         else:
             self.twitter_value = QPushButton('Auth on Twitter')
         self._main_layout.addWidget(self.twitter_value,0,1)
         self.connect(self.twitter_value,SIGNAL('clicked()'),self.request_twitter_access_or_clear)
 
-        if self.settings.value('identica_access_token').toBool():
+        if self.settings.value('identica_access_token')=='true':
             self.identica_value = QPushButton('Clear Identi.ca Auth')
         else:
             self.identica_value = QPushButton('Auth on Identi.ca')
@@ -706,16 +742,25 @@ class KhweeteurWin(QMainWindow):
         self.setupMain()
 
         self.worker = None
-        self.tweetsModel.display_screenname = self.settings.value("displayUser").toBool()
-        self.tweetsModel.display_timestamp = self.settings.value("displayTimestamp").toBool()
-        self.tweetsModel.display_avatar = self.settings.value("displayAvatar").toBool()
+        print 'Pyside debug:',self.settings.value("displayUser")
+#        self.tweetsModel.display_screenname = self.settings.value("displayUser").toBool()
+#        self.tweetsModel.display_timestamp = self.settings.value("displayTimestamp").toBool()
+#        self.tweetsModel.display_avatar = self.settings.value("displayAvatar").toBool()
+        #Pyside
+        self.tweetsModel.display_screenname = (self.settings.value("displayUser")!='0')
+        self.tweetsModel.display_timestamp = (self.settings.value("displayTimestamp")!='0')
+        self.tweetsModel.display_avatar = (self.settings.value("displayAvatar")!='0')
+        print 'DEBUG Pyside displayAvatar: ',self.settings.value("displayAvatar")
         self.nw = NetworkManager(self.refresh_timeline)
         self.notifications = KhweeteurNotification()
 
         self.timer = QTimer()
         self.connect(self.timer, SIGNAL("timeout()"), self.timed_refresh)
-        if (self.settings.value("refreshInterval").toInt()[0]>0):
-            self.timer.start(self.settings.value("refreshInterval").toInt()[0]*60*1000)
+#        if (self.settings.value("refreshInterval").toInt()[0]>0):
+#            self.timer.start(self.settings.value("refreshInterval").toInt()[0]*60*1000)
+        #Pyside
+        if (int(self.settings.value("refreshInterval"))>0):
+            self.timer.start(int(self.settings.value("refreshInterval"))*60*1000)
 
         if self.search_keyword == None:
             self.open_saved_search()
@@ -749,7 +794,8 @@ class KhweeteurWin(QMainWindow):
         self.tb_text = QLineEdit()
         self.tb_text_replyid = 0
         self.tb_text_replytext = ''
-        self.tb_text.enabledChange(True)
+        #Pyside
+#        self.tb_text.enabledChange(True)
         self.toolbar.addWidget(self.tb_text)
 
         self.tb_charCounter = QLabel('140')
@@ -772,7 +818,7 @@ class KhweeteurWin(QMainWindow):
 
 
     def countChar(self,text):
-        self.tb_charCounter.setText(unicode(140-text.count()))
+        self.tb_charCounter.setText(unicode(140-len(text)))
 
     def reply(self,index):
         user = self.tweetsModel._items[index.row()][2]
@@ -789,10 +835,10 @@ class KhweeteurWin(QMainWindow):
                 tweetid = self.tweetsModel._items[index.row()][1]
                 print 'DEBUG Retweet:',tweetid
                 try:
-                    if self.settings.value("twitter_access_token_key").toString()!='':     
+                    if self.settings.value("twitter_access_token_key")!='':     
                         api = twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, 
-                                          access_token_key=str(self.settings.value("twitter_access_token_key").toString()),
-                                          access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
+                                          access_token_key=str(self.settings.value("twitter_access_token_key")),
+                                          access_token_secret=str(self.settings.value("twitter_access_token_secret")))
                         api.PostRetweet(tweetid)
                         self.notifications.info('Retweet send to Twitter')
                 except (twitter.TwitterError,StandardError),e:
@@ -803,11 +849,11 @@ class KhweeteurWin(QMainWindow):
                         self.notifications.warn('Retweet to twitter failed : '+str(e))
                         print e                     
                 try:
-                    if self.settings.value("identica_access_token_key").toString()!='': 
+                    if self.settings.value("identica_access_token_key")!='': 
                         api = twitter.Api(base_url='http://identi.ca/api/',username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
                                           password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
-                                          access_token_key=str(self.settings.value("identica_access_token_key").toString()),
-                                          access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))    
+                                          access_token_key=str(self.settings.value("identica_access_token_key")),
+                                          access_token_secret=str(self.settings.value("identica_access_token_secret")))    
                         api.PostRetweet(tweetid)
                         self.notifications.info('Retweet send to Identi.ca')
                 except (twitter.TwitterError,StandardError),e:
@@ -825,23 +871,23 @@ class KhweeteurWin(QMainWindow):
                 if status_text.startswith(self.tb_text_replytext):
                     self.tb_text_replyid = 0
                     
-                if self.settings.value("twitter_access_token_key").toString()!='':     
+                if self.settings.value("twitter_access_token_key")!='':     
                     api = twitter.Api(
                                       username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, 
-                                      access_token_key=str(self.settings.value("twitter_access_token_key").toString()),
-                                      access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
-                    if self.settings.value('useSerialization').toBool():
+                                      access_token_key=str(self.settings.value("twitter_access_token_key")),
+                                      access_token_secret=str(self.settings.value("twitter_access_token_secret")))
+                    if (self.settings.value('useSerialization')!='0'):
                         status = api.PostSerializedUpdates(status_text,in_reply_to_status_id=self.tb_text_replyid)
                     else:
                         status = api.PostUpdate(status_text,in_reply_to_status_id=self.tb_text_replyid)
                     self.notifications.info('Tweet send to Twitter')
 
-                if self.settings.value("identica_access_token_key").toString()!='':     
+                if self.settings.value("identica_access_token_key")!='':     
                     api = twitter.Api(base_url='http://identi.ca/api/',username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
                                       password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
-                                      access_token_key=str(self.settings.value("identica_access_token_key").toString()),
-                                      access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))
-                    if self.settings.value('useSerialization').toBool():
+                                      access_token_key=str(self.settings.value("identica_access_token_key")),
+                                      access_token_secret=str(self.settings.value("identica_access_token_secret")))
+                    if(self.settings.value('useSerialization')!='0'):
                         status = api.PostSerializedUpdates(status_text,in_reply_to_status_id=self.tb_text_replyid)
                     else:
                         status = api.PostUpdate(status_text,in_reply_to_status_id=self.tb_text_replyid)
@@ -865,12 +911,12 @@ class KhweeteurWin(QMainWindow):
 #        if self.search_keyword == None:
         self.tweetsModel.serialize(self.search_keyword)
         counter=self.tweetsModel.getNewAndReset()
-        if (counter>0) and (self.settings.value('useNotification').toBool()) and not (self.isActiveWindow()):
+        if (counter>0) and (self.settings.value('useNotification')!='0') and not (self.isActiveWindow()):
             self.notifications.notify('Khweeteur',str(counter)+' new tweet(s)',count=counter)
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
 
     def do_refresh_now(self):
-        print type(self.settings.value('useNotification').toString()),self.settings.value('useNotification').toString()
+        #print type(self.settings.value('useNotification')),self.settings.value('useNotification')
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
         self.worker = KhweeteurWorker(search_keyword=self.search_keyword)
         self.connect(self.worker, SIGNAL("newStatus(PyQt_PyObject)"), self.tweetsModel.addStatus)
@@ -899,12 +945,16 @@ class KhweeteurWin(QMainWindow):
             print 'isFinished()', self.worker.isFinished()
 
     def restartTimer(self):
-        self.tweetsModel.display_screenname = self.settings.value("displayUser").toBool()
-        self.tweetsModel.display_timestamp = self.settings.value("displayTimestamp").toBool()
-        self.tweetsModel.display_avatar = self.settings.value("displayAvatar").toBool()
+#        self.tweetsModel.display_screenname = self.settings.value("displayUser").toBool()
+#        self.tweetsModel.display_timestamp = self.settings.value("displayTimestamp").toBool()
+#        self.tweetsModel.display_avatar = self.settings.value("displayAvatar").toBool()
+        #Pyside
+        self.tweetsModel.display_screenname = (self.settings.value("displayUser")!='0')
+        self.tweetsModel.display_timestamp = (self.settings.value("displayTimestamp")!='0')
+        self.tweetsModel.display_avatar = (self.settings.value("displayAvatar")!='0')
         QObject.emit(self.tweetsModel, SIGNAL("dataChanged(const QModelIndex&, const QModelIndex &)"), self.tweetsModel.createIndex(0,0), self.tweetsModel.createIndex(0,len(self.tweetsModel._items)))
-        if (self.settings.value("refreshInterval").toInt()[0]>0):
-            self.timer.start(self.settings.value("refreshInterval").toInt()[0]*60*1000)
+        if (int(self.settings.value("refreshInterval"))>0):
+            self.timer.start(int(self.settings.value("refreshInterval"))*60*1000)
         else:
             self.timer.stop()
 
@@ -923,7 +973,10 @@ class KhweeteurWin(QMainWindow):
                 QKeySequence(self.tr("Ctrl+T", "Retweet")))
                 
         if self.search_keyword != None:
-            keywords = self.settings.value('savedSearch').toPyObject()
+    #        keywords = self.settings.value('savedSearch').toPyObject()
+            #Pyside
+            print 'Pyside debug',self.settings.value('savedSearch')
+            keywords = self.settings.value('savedSearch')
             if keywords != None:
                 if self.search_keyword in keywords:
                     fileMenu.addAction(self.tr("&Remove Search"), self.del_search)
@@ -935,28 +988,39 @@ class KhweeteurWin(QMainWindow):
         fileMenu.addAction(self.tr("&About"), self.do_about)
 
     def del_search(self):
-        keywords = self.settings.value('savedSearch').toPyObject()
-        if keywords == None:
+#        keywords = self.settings.value('savedSearch').toPyObject()
+        #Pyside
+        print 'Pyside debug',self.settings.value('savedSearch')
+        keywords = self.settings.value('savedSearch')
+        if (keywords == None) or (type(keywords) != tuple):
             keywords = []
         else:
             index = keywords.indexOf(self.search_keyword)
             if index>=0:
                 keywords.removeAt(index)
-        self.settings.setValue('savedSearch',QVariant(keywords))
+#        self.settings.setValue('savedSearch',QVariant(keywords))
+        self.settings.setValue('savedSearch',(keywords))
         self.close()
                                 
     def save_search(self):
-        keywords = self.settings.value('savedSearch').toPyObject()
-        if keywords == None:
+#        keywords = self.settings.value('savedSearch').toPyObject()
+        #Pyside
+        print 'Pyside debug',self.settings.value('savedSearch')
+        keywords = self.settings.value('savedSearch')
+        if (keywords != None) and (type(keywords) == tuple):
             keywords = []
         keywords.append(self.search_keyword)
-        self.settings.setValue('savedSearch',QVariant(keywords))
+#        self.settings.setValue('savedSearch',QVariant(keywords))
+        self.settings.setValue('savedSearch',(keywords))
                                 
     def open_saved_search(self):
-        keywords = self.settings.value('savedSearch').toPyObject()
-        if keywords != None:
+#        keywords = self.settings.value('savedSearch').toPyObject()
+        #Pyside
+        keywords = self.settings.value('savedSearch')
+        print 'Pyside debug open_saved_search',type(keywords),self.settings.value('savedSearch')
+        if (keywords != None) and (type(keywords) == tuple):
             for keyword in keywords:
-                self.do_search(keyword)
+                self.do_search(keyword)            
     
     def open_search(self):
         search_keyword, ok = QInputDialog.getText(self, 'Search', 'Enter the search keyword(s) :')
